==> open-xchange-freebusy_7.2.1.orig.tar.bz2: open-xchange-freebusy-7.2.1/com.openexchange.freebusy.service.impl/src/com/openexchange/freebusy/service/impl/FreeBusyProviderRegistry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.freebusy.service.impl;

import java.util.ArrayList;
import java.util.List;
import org.apache.commons.logging.Log;
import com.openexchange.freebusy.provider.FreeBusyProvider;
import com.openexchange.log.LogFactory;

/**
 * {@link FreeBusyProviderRegistry}
 *
 * Holds references to registered {@link FreeBusyProvider}s
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class FreeBusyProviderRegistry {

    private final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FreeBusyProviderRegistry.class));

    private final List<FreeBusyProvider> providers;

    /**
     * Initializes a new {@link FreeBusyProviderRegistry}.
     */
    public FreeBusyProviderRegistry() {
        super();
        this.providers = new ArrayList<FreeBusyProvider>();
        LOG.debug("initialized.");
    }

    /**
     * Adds a {@link FreeBusyProvider} service.
     *
     * @param service The service to add
     */
    public void add(FreeBusyProvider service) {
        LOG.info("adding free/busy provider: " + service);
        this.providers.add(service);
    }

    /**
     * Removes a {@link FreeBusyProvider} service.
     *
     * @param service The service to remove
     */
    public void remove(FreeBusyProvider service) {
        LOG.info("removing free/busy provider: " + service);
        this.providers.remove(service);
    }

    /**
     * Gets all registered free/busy provider services.
     *
     * @return The free/busy providers
     */
    public List<FreeBusyProvider> getProviders() {
        return this.providers;
    }

}

==> open-xchange-freebusy_7.4.2.orig.tar.bz2: open-xchange-freebusy-7.4.2/com.openexchange.freebusy.service.impl/src/com/openexchange/freebusy/service/impl/FreeBusyProviderRegistry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.freebusy.service.impl;

import java.util.ArrayList;
import java.util.List;
import com.openexchange.freebusy.provider.FreeBusyProvider;

/**
 * {@link FreeBusyProviderRegistry}
 *
 * Holds references to registered {@link FreeBusyProvider}s
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class FreeBusyProviderRegistry {

    private final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(FreeBusyProviderRegistry.class);

    private final List<FreeBusyProvider> providers;

    /**
     * Initializes a new {@link FreeBusyProviderRegistry}.
     */
    public FreeBusyProviderRegistry() {
        super();
        this.providers = new ArrayList<FreeBusyProvider>();
        LOG.debug("initialized.");
    }

    /**
     * Adds a {@link FreeBusyProvider} service.
     *
     * @param service The service to add
     */
    public void add(FreeBusyProvider service) {
        LOG.info("adding free/busy provider: {}", service);
        this.providers.add(service);
    }

    /**
     * Removes a {@link FreeBusyProvider} service.
     *
     * @param service The service to remove
     */
    public void remove(FreeBusyProvider service) {
        LOG.info("removing free/busy provider: {}", service);
        this.providers.remove(service);
    }

    /**
     * Gets all registered free/busy provider services.
     *
     * @return The free/busy providers
     */
    public List<FreeBusyProvider> getProviders() {
        return this.providers;
    }

}
